@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: memory.h,v 1.4 2002/04/11 01:26:19 cosine Exp $
+ * $Id: memory.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
  */
 
 #ifndef INCLUDED_memory_h
@@ -24,8 +24,8 @@ struct MemFormat
   unsigned char delim; /* one of 'x', 'o', 'b', 'd' */
   char *desc;          /* description (ie: octal, hex, etc) */
   char *fmt;           /* format string */
-  char *blank;         /* blank string */
   int epl;             /* number of elements to display per line */
+  int cpe;             /* number of characters per element */
 };
 
 /*
