@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: regs-x86.c,v 1.15 2002/06/29 14:57:55 cosine Exp $
+ * $Id: regs-x86.c,v 1.5 2003/09/07 17:52:08 cosine Exp $
  *
  * This module contains routines dealing with x86 registers which are common to
  * all operating systems.
@@ -25,14 +25,11 @@
 
 #include "libDebug.h"
 
-/*
- * libString includes
- */
 #include "Strn.h"
 
 /*
- * List of x86 registers - the elements in this array are ordered to correspond
- * to the REG_xxx indices defined in regs-x86.h
+ * List of x86 registers - the elements in this array are ordered to
+ * correspond to the REG_xxx indices defined in regs-x86.h
  */
 struct x86RegInfo x86Registers[] = {
   { "eax", 4, R_BITS32|R_GENERAL, (void *) 0 },
@@ -96,14 +93,14 @@ struct x86RegInfo x86Registers[] = {
   { "st6", 0, R_BITS80|R_FPU|R_FPU_DATA, (void *) 0 },
   { "st7", 0, R_BITS80|R_FPU|R_FPU_DATA, (void *) 0 },
 
-  { "fctrl", 0, R_BITS16|R_FPU, (void *) 0 },
-  { "fstat", 0, R_BITS16|R_FPU, (void *) 0 },
-  { "ftag", 0, R_BITS16|R_FPU, (void *) 0 },
-  { "fip", 0, R_BITS32|R_FPU, (void *) 0 },
-  { "fcs", 0, R_BITS16|R_FPU, (void *) 0 },
-  { "fopcode", 0, R_BITS16|R_FPU, (void *) 0 },
-  { "foo", 0, R_BITS32|R_FPU, (void *) 0 },
-  { "fos", 0, R_BITS32|R_FPU, (void *) 0 },
+  { "fctrl", 2, R_BITS16|R_FPU, (void *) 0 },
+  { "fstat", 2, R_BITS16|R_FPU, (void *) 0 },
+  { "ftag", 2, R_BITS16|R_FPU, (void *) 0 },
+  { "fipoff", 4, R_BITS32|R_FPU, (void *) 0 },
+  { "fipseg", 2, R_BITS16|R_FPU, (void *) 0 },
+  { "fopcode", 2, R_BITS16|R_FPU, (void *) 0 },
+  { "fooff", 4, R_BITS32|R_FPU, (void *) 0 },
+  { "foseg", 4, R_BITS32|R_FPU, (void *) 0 },
 
   /*
    * MMX registers
@@ -149,9 +146,9 @@ x86findRegisterDebug(struct debugWorkspace *ws, char *name)
 
 /*
 x86readRegisterDebug()
-  Read the contents of a specified register. Before calling this function,
-x86getRegistersDebug() should be called to obtain the latest register contents via
-ptrace
+  Read the contents of a specified register. Before calling this
+function, x86getRegistersDebug() should be called to obtain the
+latest register contents via ptrace
 
 Inputs: ws     - debug workspace
         rptr   - pointer to a register in x86Registers[]
@@ -159,11 +156,11 @@ Inputs: ws     - debug workspace
 
 Return: size of register in bytes
 
-Side effects: regVal.lvalue is set to the register's value if it is a 16 or 32 bit
-              register
+Side effects: regVal.lvalue is set to the register's value if it
+              is a 16 or 32 bit register
 
-              If it is a fpu data register, regVal.stptr is set to the position
-              on the fpu data stack of the register
+              If it is a fpu data register, regVal.stptr is set to
+              the position on the fpu data stack of the register
 */
 
 size_t
@@ -196,10 +193,11 @@ x86readRegisterDebug(struct debugWorkspace *ws, struct x86RegInfo *rptr,
     if (rptr->flags & R_BITS8)
     {
       /*
-       * We only get here from x86setRegisterDebug(), and we do not want to "and"
-       * this value to strip off the last byte, since we may be trying to set
-       * the ah/bh/ch/dh registers which don't occur in the last byte. So let
-       * x86setRegisterDebug() worry about that stuff.
+       * We only get here from x86setRegisterDebug(), and we do not
+       * want to "and" this value to strip off the last byte, since
+       * we may be trying to set the ah/bh/ch/dh registers which don't
+       * occur in the last byte. So let x86setRegisterDebug() worry
+       * about that stuff.
        */
       size = 1;
       regVal->lvalue = *((unsigned long *) rptr->valptr);
@@ -223,15 +221,16 @@ x86readRegisterDebug(struct debugWorkspace *ws, struct x86RegInfo *rptr,
 
 /*
 x86printRegistersDebug()
-  Traverse the list of registers and call a given callback function with each
-register's name and value.
+  Traverse the list of registers and call a given callback function
+with each register's name and value.
 
 Inputs: ws           - debug workspace
-        regindex     - optional index of x86Registers to display (-1 to display all
-                       registers)
+        regindex     - optional index of x86Registers to display
+                       (-1 to display all registers)
         flags        - flags (see REGFL_xxx in libDebug.h)
-        callback     - callback function: void *callback(struct debugRegisterInfo *regInfo,
-                                                         void *args);
+        callback     - callback function:
+                       void *callback(struct debugRegisterInfo *regInfo,
+                                      void *args);
         callbackArgs - arguments to callback function
 
 Return: 1 if successful
@@ -239,8 +238,9 @@ Return: 1 if successful
 */
 
 int
-x86printRegistersDebug(struct debugWorkspace *ws, int regindex, unsigned int flags,
-                             void (*callback)(), void *callbackArgs)
+x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
+                       unsigned int flags, void (*callback)(),
+                       void *callbackArgs)
 
 {
   struct x86fpuInfo *fpuState;
@@ -357,40 +357,40 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex, unsigned int fla
 
       ws->regInfo.size = 4;
 
-      strcpy(ws->regInfo.name, "fctrl");
+      strcpy(ws->regInfo.name, x86Registers[REG_FCTRL].name);
       ws->regInfo.value = (unsigned long) fpuState->fctrl;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      strcpy(ws->regInfo.name, "fstat");
+      strcpy(ws->regInfo.name, x86Registers[REG_FSTAT].name);
       ws->regInfo.value = (unsigned long) fpuState->fstat;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      strcpy(ws->regInfo.name, "ftag");
+      strcpy(ws->regInfo.name, x86Registers[REG_FTAG].name);
       ws->regInfo.value = (unsigned long) fpuState->ftag;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      ws->regInfo.size = 2;
-      strcpy(ws->regInfo.name, "fipseg");
+      ws->regInfo.size = 4;
+      strcpy(ws->regInfo.name, x86Registers[REG_FCS].name);
       ws->regInfo.value = fpuState->fcs;
       (*callback)(&(ws->regInfo), callbackArgs);
 
       ws->regInfo.size = 8;
-      strcpy(ws->regInfo.name, "fipoff");
+      strcpy(ws->regInfo.name, x86Registers[REG_FIP].name);
       ws->regInfo.value = fpuState->fip;
       (*callback)(&(ws->regInfo), callbackArgs);
 
       ws->regInfo.size = 2;
-      strcpy(ws->regInfo.name, "foseg");
+      strcpy(ws->regInfo.name, x86Registers[REG_FOSEG].name);
       ws->regInfo.value = fpuState->foseg;
       (*callback)(&(ws->regInfo), callbackArgs);
 
       ws->regInfo.size = 8;
-      strcpy(ws->regInfo.name, "fooff");
+      strcpy(ws->regInfo.name, x86Registers[REG_FOOFF].name);
       ws->regInfo.value = fpuState->fooff;
       (*callback)(&(ws->regInfo), callbackArgs);
 
       ws->regInfo.size = 4;
-      strcpy(ws->regInfo.name, "fop");
+      strcpy(ws->regInfo.name, x86Registers[REG_FOPCODE].name);
       ws->regInfo.value = fpuState->fopcode;
       (*callback)(&(ws->regInfo), callbackArgs);
 
@@ -550,10 +550,10 @@ x86setRegisterDebug(struct debugWorkspace *ws, int regindex, char *value)
   struct x86RegInfo *rptr;
   unsigned int andmask; /* mask to and old register value with */
   int shl;              /* number of bits to shift new value left */
-  long lval;            /* long value if general register */
+  unsigned long lval;   /* long value if general register */
   long double dval;     /* double value if fpu data register (*must* be long double) */
-  long newval;
-  long curval;
+  unsigned long newval;
+  unsigned long curval;
   size_t size;
   struct x86RegValue regVal;
   char *endptr;
@@ -566,7 +566,7 @@ x86setRegisterDebug(struct debugWorkspace *ws, int regindex, char *value)
   if ((rptr->flags & R_GENERAL) ||
       ((rptr->flags & R_FPU) && !(rptr->flags & R_FPU_DATA)))
   {
-    lval = strtol(value, &endptr, 0);
+    lval = strtoul(value, &endptr, 0);
     if ((endptr == value) || (*endptr != '\0'))
       return (-2); /* invalid value */
 
@@ -636,7 +636,7 @@ x86setRegisterDebug(struct debugWorkspace *ws, int regindex, char *value)
     curval |= (newval << shl);
 
     /* set the actual register */
-    regVal.lvalue = (unsigned long) curval;
+    regVal.lvalue = curval;
     if (!x86writeRegisterDebug(ws, rptr, &regVal))
       return (-1); /* ptrace error */
   } /* if (rptr->flags & R_GENERAL) */
@@ -655,6 +655,10 @@ x86setRegisterDebug(struct debugWorkspace *ws, int regindex, char *value)
     if (!x86writeRegisterDebug(ws, rptr, &regVal))
       return (-1); /* ptrace error */
   } /* if (rptr->flags & R_FPU_DATA) */
+  else if (rptr->flags & R_MMX)
+  {
+    printf("setting mmx reg, value = %s\n", value);
+  } /* if (rptr->flags & R_MMX) */
 
   return (1);
 } /* x86setRegisterDebug() */
