@@ -8,10 +8,11 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: trace-x86.c,v 1.32 2002/06/15 01:35:53 cosine Exp $
+ * $Id: trace-x86.c,v 1.2 2003/08/27 20:38:15 cosine Exp $
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <assert.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -30,12 +31,8 @@
 #include "configDb.h"
 #include "libDebug.h"
 
-/*
- * libString includes
- */
-#include "alloc.h"
-
-static int x86GetDebugProcessStatus(struct debugWorkspace *ws, int ptfunc, int waitval,
+static int x86GetDebugProcessStatus(struct debugWorkspace *ws,
+                                    int ptfunc, int waitval,
                                     int *data);
 static int x86DoSingleStep(struct debugWorkspace *ws, int *data);
 static int x86DoContinue(struct debugWorkspace *ws, int *data);
@@ -626,7 +623,7 @@ x86stepOverDebug(struct debugWorkspace *ws, int num, int *data)
       if (dret > 0)
         slen = IsSubroutine(opbuf);
 
-      MyFree(opbuf);
+      free(opbuf);
     }
 
     if (slen)
@@ -991,7 +988,7 @@ x86dumpMemoryDebug(struct debugWorkspace *ws, char **buf, unsigned long start, l
   addr = start;
   end = start + bytes;
 
-  *buf = (char *) MyMalloc(bytes + 1);
+  *buf = (char *) malloc(bytes + 1);
   bufptr = *buf;
 
   ret = 0;
