@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_clear.c,v 1.6 2002/04/11 01:26:20 cosine Exp $
+ * $Id: c_clear.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <stdlib.h>
@@ -22,9 +22,12 @@
 /*
 c_clear()
   Clear the current active window
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_clear(struct aldWorkspace *ws, int ac, char **av)
 
 {
@@ -42,7 +45,7 @@ c_clear(struct aldWorkspace *ws, int ac, char **av)
     if ((endptr == av[1]) || (*endptr != '\0'))
     {
       Print(ws, P_COMMAND, MSG_INVNUM, av[1]);
-      return;
+      return (0);
     }
 
     if (!(frame = FindFrameByNumber(winnum)))
@@ -51,11 +54,13 @@ c_clear(struct aldWorkspace *ws, int ac, char **av)
             P_COMMAND,
             "Invalid window number: %d",
             winnum);
-      return;
+      return (0);
     }
   }
 
   ClearScrollWindow(frame);
 
 #endif /* USE_CURSES */
+
+  return (1);
 } /* c_clear() */
