@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_detach.c,v 1.2 2002/04/12 01:57:55 cosine Exp $
+ * $Id: c_detach.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <errno.h>
@@ -26,9 +26,12 @@ c_detach()
 
 Format for this command:
   detach
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_detach(struct aldWorkspace *ws, int ac, char **av)
 
 {
@@ -43,7 +46,7 @@ c_detach(struct aldWorkspace *ws, int ac, char **av)
             P_ERROR,
             MSG_PTERR,
             strerror(errno));
-      return;
+      return (0);
 
       break; /* not reached */
     } /* case 0 */
@@ -53,7 +56,7 @@ c_detach(struct aldWorkspace *ws, int ac, char **av)
       Print(ws,
             P_ERROR,
             "error: Not currently attached to a process");
-      return;
+      return (0);
 
       break; /* not reached */
     }
@@ -69,4 +72,6 @@ c_detach(struct aldWorkspace *ws, int ac, char **av)
   }
 
   awClearAttached(ws);
+
+  return (1);
 } /* c_detach() */
