@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_enable.c,v 1.5 2002/04/11 01:26:20 cosine Exp $
+ * $Id: c_enable.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <stdlib.h>
@@ -30,37 +30,40 @@
 /*
 c_enable()
   Enable a breakpoint
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_enable(struct aldWorkspace *ws, int ac, char **av)
 
 {
-  long num;
+  unsigned long num;
   char *endptr;
   struct Breakpoint *ptr;
 
   if (ac < 2)
   {
     Print(ws, P_COMMAND, "Syntax: enable <number | all>");
-    return;
+    return (0);
   }
 
   if (!Strcasecmp(av[1], "all"))
     num = 0;
   else
   {
-    num = strtol(av[1], &endptr, 0);
+    num = strtoul(av[1], &endptr, 0);
     if ((endptr == av[1]) || (*endptr != '\0'))
     {
       Print(ws, P_ERROR, MSG_INVADDR, av[1]);
-      return;
+      return (0);
     }
   }
 
   if (num)
   {
-    ptr = findBreakpointByNumber(ws->debugWorkspace_p, num);
+    ptr = findBreakpointByNumber(ws->debugWorkspace_p, (unsigned int) num);
     if (!ptr)
       Print(ws, P_ERROR, "No such breakpoint number: %ld", num);
     else
@@ -68,4 +71,6 @@ c_enable(struct aldWorkspace *ws, int ac, char **av)
   }
   else
     activateBreakpoint(ws->debugWorkspace_p, 0);
+
+  return (1);
 } /* c_enable() */
