@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_help.c,v 1.3 2002/04/11 01:26:21 cosine Exp $
+ * $Id: c_help.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include "help.h"
@@ -17,11 +17,16 @@
 /*
 c_help()
  Give user some help
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_help(struct aldWorkspace *ws, int ac, char **av)
 
 {
   GiveHelp(ws, ac, av);
+
+  return (1);
 } /* c_help() */
