@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_ignore.c,v 1.5 2002/04/11 01:26:21 cosine Exp $
+ * $Id: c_ignore.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <stdlib.h>
@@ -25,43 +25,48 @@
 /*
 c_ignore()
   Set the ignore count for a breakpoint
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_ignore(struct aldWorkspace *ws, int ac, char **av)
 
 {
-  long num,
-       count;
+  unsigned long num;
+  long count;
   char *endptr;
   struct Breakpoint *ptr;
 
   if (ac < 3)
   {
     Print(ws, P_COMMAND, "Syntax: ignore <number> <count>");
-    return;
+    return (0);
   }
 
-  num = strtol(av[1], &endptr, 0);
+  num = strtoul(av[1], &endptr, 0);
   if ((endptr == av[1]) || (*endptr != '\0'))
   {
     Print(ws, P_ERROR, MSG_INVNUM, av[1]);
-    return;
+    return (0);
   }
 
-  ptr = findBreakpointByNumber(ws->debugWorkspace_p, num);
+  ptr = findBreakpointByNumber(ws->debugWorkspace_p, (unsigned int) num);
   if (!ptr)
   {
     Print(ws, P_ERROR, "No such breakpoint number: %ld", num);
-    return;
+    return (0);
   }
 
   count = strtol(av[2], &endptr, 0);
   if ((endptr == av[2]) || (*endptr != '\0'))
   {
     Print(ws, P_ERROR, MSG_INVNUM, av[2]);
-    return;
+    return (0);
   }
 
   setIgnoreCount(ptr, count);
+
+  return (1);
 } /* c_ignore() */
