@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_load.c,v 1.7 2002/04/12 01:57:55 cosine Exp $
+ * $Id: c_load.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include "load.h"
@@ -20,21 +20,26 @@
 /*
 c_load()
  Load a new file
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_load(struct aldWorkspace *ws, int ac, char **av)
 
 {
   if (ac < 2)
   {
     Print(ws, P_COMMAND, "Syntax: load <filename>");
-    return;
+    return (0);
   }
 
-  procLoad(ws->loadWorkspace_p, av[1]);
+  loadFile(ws, av[1]);
 
   startDebug(ws->debugWorkspace_p, av[1], ModeCurses);
 
   awSetFileLoaded(ws);
+
+  return (1);
 } /* c_load() */
