@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_quit.c,v 1.3 2002/04/10 01:57:44 cosine Exp $
+ * $Id: c_quit.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include "load.h"
@@ -18,11 +18,18 @@
 /*
 c_quit()
  Terminate the program
+
+Return: -1
 */
 
-void
+int
 c_quit(struct aldWorkspace *ws, int ac, char **av)
 
 {
-  MyExit(0);
+  /*
+   * Save settings to configuration file
+   */
+  writeRC(ws);
+
+  return (-1);
 } /* c_quit() */
