@@ -8,9 +8,10 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_set.c,v 1.6 2002/04/13 17:52:39 cosine Exp $
+ * $Id: c_set.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
+#include "alddefs.h"
 #include "command.h"
 #include "main.h"
 #include "print.h"
@@ -19,31 +20,30 @@
 /*
 c_set()
   Configure various settings
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_set(struct aldWorkspace *ws, int ac, char **av)
 
 {
   struct Command *cptr;
   unsigned int flags;
+  int ret;
+  char errbuf[MAXLINE];
 
   if (ac < 2)
   {
     DisplaySettings(ws);
-    return;
+    return (0);
   }
 
   flags = 0;
-  cptr = FindCommand(setcmds, av[1], &flags);
-  if (cptr)
-  {
-    /*
-     * Call cptr->func to execute command
-     */
-    (*cptr->funcptr)(ws, ac, av, 0);
-  }
-  else
+  cptr = FindCommand(setCmds, av[1], &flags);
+
+  if (!cptr)
   {
     /*
      * They gave us an invalid setting
@@ -53,5 +53,48 @@ c_set(struct aldWorkspace *ws, int ac, char **av)
           "%s command: set %s",
           (flags & C_AMBIGUOUS) ? "Ambiguous" : "Unknown",
           av[1]);
+    return (0);
   }
+
+  /*
+   * Call cptr->func to execute command
+   */
+  ret = (*cptr->funcptr)(ws, ac, av, 0, errbuf);
+
+  switch (ret)
+  {
+    /* general error */
+    case 0:
+    {
+      Print(ws,
+            P_COMMAND,
+            "%s",
+            errbuf);
+
+      return (0);
+
+      break;
+    }
+
+    /* syntax error */
+    case 1:
+    {
+      Print(ws,
+            P_COMMAND,
+            "Syntax: %s",
+            errbuf);
+
+      return (0);
+
+      break;
+    }
+
+    /* success */
+    default:
+    {
+      break;
+    }
+  }
+
+  return (1);
 } /* c_set() */
