@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_tbreak.c,v 1.6 2002/04/24 19:34:06 cosine Exp $
+ * $Id: c_tbreak.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <stdlib.h>
@@ -27,9 +27,12 @@
 /*
 c_tbreak()
   Set a temporary breakpoint at given address
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_tbreak(struct aldWorkspace *ws, int ac, char **av)
 
 {
@@ -40,14 +43,14 @@ c_tbreak(struct aldWorkspace *ws, int ac, char **av)
   if (ac < 2)
   {
     Print(ws, P_COMMAND, "Syntax: tbreak <address>");
-    return;
+    return (0);
   }
 
   address = strtoul(av[1], &endptr, 0);
   if ((endptr == av[1]) || (*endptr != '\0'))
   {
     Print(ws, P_ERROR, MSG_INVADDR, av[1]);
-    return;
+    return (0);
   }
 
   num = newBreakpoint(ws->debugWorkspace_p, address, BK_TEMPORARY);
@@ -66,4 +69,6 @@ c_tbreak(struct aldWorkspace *ws, int ac, char **av)
       num,
       address);
   }
+
+  return (1);
 } /* c_tbreak() */
