@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_unload.c,v 1.5 2002/04/13 18:16:56 cosine Exp $
+ * $Id: c_unload.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include "load.h"
@@ -19,12 +19,17 @@
 /*
 c_unload()
   Unload current file
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_unload(struct aldWorkspace *ws, int ac, char **av)
 
 {
-  procUnload(ws->loadWorkspace_p);
+  unloadFile(ws);
   endProcess(ws);
+
+  return (1);
 } /* c_unload() */
