@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_window.c,v 1.3 2002/04/11 01:26:22 cosine Exp $
+ * $Id: c_window.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <stdlib.h>
@@ -22,9 +22,12 @@
 /*
 c_window()
   List/manipulate curses windows
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_window(struct aldWorkspace *ws, int ac, char **av)
 
 {
@@ -54,11 +57,13 @@ c_window(struct aldWorkspace *ws, int ac, char **av)
     if ((endptr == av[1]) || (*endptr != '\0'))
     {
       Print(ws, P_COMMAND, MSG_INVNUM, av[1]);
-      return;
+      return (0);
     }
 
     SwitchCurrentFrame((int) num);
   }
 
 #endif /* USE_CURSES */
+
+  return (1);
 } /* c_window() */
