@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_write.c,v 1.5 2002/04/11 01:26:22 cosine Exp $
+ * $Id: c_write.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
  */
 
 #include <errno.h>
@@ -25,9 +25,12 @@ c_write()
   Dump contents of current window to a file
 
 Inputs: av[1] - filename
+
+Return: 0 upon failure
+        1 upon success
 */
 
-void
+int
 c_write(struct aldWorkspace *ws, int ac, char **av)
 
 {
@@ -48,7 +51,7 @@ c_write(struct aldWorkspace *ws, int ac, char **av)
           "Unable to open %s: %s",
           filebuf,
           strerror(errno));
-    return;
+    return (0);
   }
 
   if (DumpCurrentWindow(fp))
@@ -57,4 +60,6 @@ c_write(struct aldWorkspace *ws, int ac, char **av)
   fclose(fp);
 
 #endif /* USE_CURSES */
+
+  return (1);
 } /* c_write() */
